==> alexa-skill-test-1.0.1.tgz: package/server.js <==
var express = require('express');
var app = express();
var path = require('path');
var lrserver = require('tiny-lr')();
var pkgConfig = require('./package.json');
var webpack = require('webpack');
var webpackMiddleware = require('webpack-dev-middleware');
var webpackConf = require('./webpack.config.js');
var webpackCompiller = webpack(webpackConf);
var lambdaLocal = require('lambda-local');
var bodyParser = require('body-parser');
var colors = require('colors');

var skill = require(process.argv[2]);

var skillName = process.argv[3];

var livereloadServerConf = {
  port: 35729
};

var triggerLiveReloadChanges = function() {
  lrserver.changed({
    body: {
      files: [webpackConf.output.filename]
    }
  });
};

lrserver.listen(livereloadServerConf.port, triggerLiveReloadChanges);

webpackCompiller.plugin('done', triggerLiveReloadChanges);

app.use(bodyParser.json());
app.use(bodyParser.urlencoded({
  extended: true
}));

app.use(webpackMiddleware(webpackCompiller));
app.use(require('connect-livereload')(livereloadServerConf));

app.use(express.static(__dirname + '/public'));

app.get('/', function(req, res) {
  res.end([
    '<!doctype html>',
    '<html lang="en">',
    '<head>',
    '<meta charset="utf-8">',
    '<meta name="viewport" content="width=device-width, initial-scale=1">',
    '<title>Alexa Skills Tester - ' + skillName + '</title>',
    '</head>',
    '<body>',
    '<div id="root"></div>',
    '<script src="' + webpackConf.output.filename + '"></script>',
    '</body>',
    '</html>'
  ].join(''));
});

app.post('/lambda', function(req, res) {
  res.setHeader('Content-Type', 'application/json');

  lambdaLocal.execute({
    event: req.body.event,
    lambdaPath: process.argv[2],
    lambdaHandler: 'handler',
    timeoutMs: 3000,
    callback: function(error, data) {
        if (error) {
            res.end(JSON.stringify(data));
        } else {
            res.end(JSON.stringify(data));
        }
    }
  });
});

app.listen(3000, function() {
  console.log('Alexa Skill Test live on port 3000.')
  console.log('Open http://localhost:3000 in your browser'.green)
});

==> alexa-skill-test-1.1.0.tgz: package/server.js <==
var express = require('express');
var app = express();
var path = require('path');
var lrserver = require('tiny-lr')();
var pkgConfig = require('./package.json');
var webpack = require('webpack');
var webpackMiddleware = require('webpack-dev-middleware');
var webpackConf = require('./webpack.config.js');
var webpackCompiller = webpack(webpackConf);
var lambdaLocal = require('lambda-local');
var bodyParser = require('body-parser');
var colors = require('colors');
var debug = require('debug')('skill');

var skill = require(process.argv[2]);

var skillName = process.argv[3];

var livereloadServerConf = {
  port: 35729
};

var triggerLiveReloadChanges = function() {
  lrserver.changed({
    body: {
      files: [webpackConf.output.filename]
    }
  });
};

lrserver.listen(livereloadServerConf.port, triggerLiveReloadChanges);

webpackCompiller.plugin('done', triggerLiveReloadChanges);

app.use(bodyParser.json());
app.use(bodyParser.urlencoded({
  extended: true
}));

app.use(webpackMiddleware(webpackCompiller));
app.use(require('connect-livereload')(livereloadServerConf));

app.use(express.static(__dirname + '/public'));

app.get('/', function(req, res) {
  res.end([
    '<!doctype html>',
    '<html lang="en">',
    '<head>',
    '<meta charset="utf-8">',
    '<meta name="viewport" content="width=device-width, initial-scale=1">',
    '<title>Alexa Skills Tester - ' + skillName + '</title>',
    '</head>',
    '<body>',
    '<div id="root"></div>',
    '<script>window.SKILL_NAME = "' + skillName + '";</script>',
    '<script src="' + webpackConf.output.filename + '"></script>',
    '</body>',
    '</html>'
  ].join(''));
});

app.post('/lambda', function(req, res) {
  res.setHeader('Content-Type', 'application/json');

  debug('Lambda event:');
  debug(req.body.event);

  lambdaLocal.execute({
    event: req.body.event,
    lambdaPath: process.argv[2],
    lambdaHandler: 'handler',
    timeoutMs: 3000,
    callback: function(error, data) {
        if (error) {
          debug('Lambda returned error');
          debug(error);
          res.end(JSON.stringify(data));
        } else {
          debug('Lambda returned response')
          debug(data);
          res.end(JSON.stringify(data));
        }
    }
  });
});

app.listen(3000, function() {
  console.log('Alexa Skill Test');
  console.log('Skill: ' + skillName);
  console.log('Open http://localhost:3000 in your browser'.green)
});
